pypinfo is written and maintained by Ofek Lev.

Maintainers
-----------

- Ofek Lev <ofekmeister@gmail.com> `@ofek <https://github.com/ofek>`_

Contributors
------------

Any PGP key fingerprints are enclosed in parentheses.

- Ofek Lev <ofekmeister@gmail.com> (FFB6 B92B 30B1 7848 546E 9912 972F E913 DAD5 A46E)
- Brian Skinn <brian.skinn@gmail.com> `@bskinn <https://github.com/bskinn>`__
- Hugo van Kemenade `@hugovk <https://github.com/hugovk>`_
- `Rahiel Kasim <https://github.com/rahiel>`_ <rahielkasim@gmail.com> (2319 F356 BE56 3B82 0EFA E9B9 F682 9BE8 6B5D 2243)
